B��tla�tka

Bežné tlačítka | Obsah

Nižšie je popísané každé tlačitko.

| Kopíruje aktuálne vybraný obsah do schránky. (Ctrl+C)
| Odstráni aktuálne vybraný obsah do schránky. (Ctrl+X)
| Vloží obsah schránky do okna editoru. (Ctrl+P)
| Zhrubne text.
| Naformatuje text kurzívou.
| Podčiarkne text.
| Preškrtne text.
| Zarovná vľavo.
| Zarovná na sted.
| Zarovná vpravo.
| Zarovná do bloku.
| Zoznam s odrážkami.
| Číslovaný zoznam.
| Predsadí/zníži odsadenie
| Odsadenie/zvýši odsadenie
| Vráti späť naposledy vykonanú akciu.
| Obnový poslednú akciu.
| Vloží nový odkaz, viac o tejto funkcií v častiVložiť odkaz.
| Zruši odkaz v aktuálnom výbere/odstráni všetky vybrané odkazy.
| Vloží nový obrázok, viac o tejto funkcii v častiVložiť obrázok.
| Vyčistí kód/odstráni nechcené formatovanie. Táto funkcia sa hodí keď kopírujete obsah napríklad z kancelárskeho balíka.
| Zobrazí túto nápovedu.
| Otevorý editor s HTML zdrojom.
| Do aktuálnej pozície vloží novú 2x2 tabulku.
| Pridá riadok pred akruálny.
| Pridá riadok po aktuálny.
| Odstráni riadok.
| Pridá stĺpec pred aktuálny.
| Pridá stĺpec za aktuálny.
| Odstráni aktuálny stĺpec.
| Pridá nový vodorovný oddeľovač.
| Odstráni z výberu formatovanie.
| Vytvorý z vybraného textu dolný index.
| Vytvorý z vybreného textu horný index.

Choď na: Obsah | Nahor